from setuptools import setup, find_packages
from setuptools.command.bdist_wheel import bdist_wheel

class SignedBdistWheel(bdist_wheel):
    def finalize_options(self):
        super().finalize_options()
        self.root_is_pure = True

setup(
    name='sys_research',
    version='0.1.0',
    description='Secure research system for quantitative analysis',
    long_description=open('README.md').read(),
    long_description_content_type='text/markdown',
    author='DaBiggestPoppa',
    author_email='dabiggestpoppa@gmail.com',
    url='https://github.com/dabiggestpoppa/rose-research-backtester',
    classifiers=[
        'Programming Language :: Python :: 3',
        'License :: OSI Approved :: MIT License',
        'Operating System :: Microsoft :: Windows',
        'Development Status :: 4 - Beta',
        'Intended Audience :: Financial and Insurance Industry',
    ],
    packages=find_packages(exclude=['tests*']),
    install_requires=[
        'numpy>=1.24.0',
        'pandas>=2.0.0',
        'fastapi>=0.100.0',
        'uvicorn>=0.23.0',
        'websockets>=11.0.3',
        'aiohttp>=3.8.5',
        'cryptography>=41.0.0',
        'pyotp>=2.8.0',
        'torch>=2.0.0',
        'transformers>=4.30.0',
        'pytest>=7.4.0',
        'pytest-asyncio>=0.21.0',
        'watchdog>=3.0.0',
    ],
    python_requires='>=3.10',
    license='MIT',
    keywords='quant research security distributed-training',
    cmdclass={'bdist_wheel': SignedBdistWheel},
    setup_requires=['wheel', 'signtool'],
)
